#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concurrent-supply
version:              0.1.8
visibility:           public
id:                   concurrent-supply-0.1.8-BzJsBnPSC3JFNiJeKd4xsU
key:                  concurrent-supply-0.1.8-BzJsBnPSC3JFNiJeKd4xsU
license:              BSD-3-Clause
copyright:            Copyright (C) 2011 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/concurrent-supply/
synopsis:             A fast concurrent unique identifier supply with a pure API
description:
    A fast supply of concurrent unique identifiers suitable for use
    within a single process. Once the initial '\''Supply'\'' has been initialized,
    the remainder of the API is pure. See "Control.Concurrent.Supply" for
    details.

category:             Concurrency, Parallelism
abi:                  2e13e372151be1292d280c9f35de4b3f
exposed:              True
exposed-modules:      Control.Concurrent.Supply
import-dirs:          /usr/lib/ghc-9.6.6/site-local/concurrent-supply-0.1.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/concurrent-supply-0.1.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/concurrent-supply-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concurrent-supply
hs-libraries:         HSconcurrent-supply-0.1.8-BzJsBnPSC3JFNiJeKd4xsU
depends:
    base-4.18.2.1 ghc-prim-0.10.0
    hashable-1.4.7.0-dWjXDvhaClDIWf01xQAnA

haddock-interfaces:
    /usr/share/doc/haskell-concurrent-supply/html/concurrent-supply.haddock

haddock-html:         /usr/share/doc/haskell-concurrent-supply/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

